define(['angular', 'commonUtil'], function (angular, commonUtil) {
  angular.module('commodityManage.controller', [])
    .filter('taxPriceMarkedFilter', function () {
      return function (object) {
        if ('true' === object) {
          return '是';
        }
        if ('false' === object) {
          return '否';
        }
        if ('' === object) {
          return '';
        }
      }
    })
    .filter('discountedFilter', function () {
      return function (object) {
        if ('Y' === object) {
          return '是';
        }
        if ('N' === object) {
          return '否';
        }
        if ('' === object) {
          return '';
        }
      }
    })
    .filter('taxRateFilter', function () {
      return function (object) {
        return object * 100 + '%';
      }
    })
    .controller('commodityManage', ['$scope', '$state', '$ionicPopup', '$ionicLoading', '$filter', '$timeout', '$location', 'systemManageService', 'commodityManageService', function ($scope, $state, $ionicPopup, $ionicLoading, $filter, $timeout, $location, systemManageService, commodityManageService) {
      $scope.search = {
        codeOrName: ''
      };
      $scope.$on('$ionicView.beforeEnter',function(){
        systemManageService.getLoginInfo().then(function (response) {
          $scope.loginInfo = response.data;
          getCommodityList();
        });
        initPage();
      });
      $scope.redirectHome = function () {
        $location.path('/tab/home');
      };
      $scope.doRefresh = function () {
        initPage();
        getCommodityList();
        $scope.$broadcast("scroll.refreshComplete")
      };
      $scope.loadMore = function () {
        if (0 != $scope.totalPage && $scope.pageIndex === $scope.totalPage) {
          $scope.canLoadMoreData = false;
          return;
        }
        $scope.pageIndex++;
        getCommodityList();
        $scope.$broadcast("scroll.infiniteScrollComplete");
      };
      $scope.moreDataCanBeLoaded = function () {
        return $scope.canLoadMoreData;
      };
      $scope.deleteCommodity = function (enterpriseProductId, index) {
        $ionicPopup.confirm({
          title: '删除商品',
          template: '确定要删除吗?',
          cancelText: '取消',
          okText: '确认'
        }).then(function (res) {
          if (res) {
            commonUtil.loadingShow($ionicLoading);
            commodityManageService.deleteCommodity(enterpriseProductId).then(function (response) {
              $ionicLoading.hide();
              var popup = commonUtil.popupShow($ionicPopup, "提示", '200' === response.code ? '删除成功' : '删除失败');
              popup.then(function () {
                if ('200' === response.code) {
                  $scope.productList.splice(index, 1);
                }
              });
              commonUtil.timeout($timeout, popup);
            });
          }
        });
      }
      function initPage() {
        $scope.pageIndex = 0;
        $scope.pageSize = 6;
        $scope.totalPage = 0;
        $scope.canLoadMoreData = false;
        $scope.productList = new Array();
      }
      function getCommodityList() {
        commodityManageService.getCommodityList($scope.pageIndex, $scope.pageSize, $scope.search.codeOrName).then(function (response) {
          $scope.totalPage = response.data.pageCount;
          if (response.data.page.length > 0) {
            if (0 == $scope.productList.length) {
              $scope.productList = response.data.page;
            } else {
              angular.forEach(response.data.page, function (item) {
                $scope.productList.push(item);
              });
            }
          }
          $timeout(function () {
            if (response.data.page.length < $scope.pageSize) {
              $scope.canLoadMoreData = false;
            } else {
              $scope.canLoadMoreData = true;
            }
          }, 1000);
        });
      }
    }])
    .controller('commodityInsert', ['$scope', '$state', '$ionicModal', '$ionicPopup', '$filter', '$ionicLoading', '$timeout', '$location', 'commodityManageService', 'systemManageService', function ($scope, $state, $ionicModal, $ionicPopup, $filter, $ionicLoading, $timeout, $location, commodityManageService, systemManageService) {
      $scope.search = {
        codeOrName: ''
      };
      $scope.isExistEnterpriseCommodityCode = false;
      systemManageService.getLoginInfo().then(function (response) {
        $scope.loginInfo = response.data;
      });
      commodityManageService.getEnterpriseTaxRateList().then(function (response) {
        $scope.taxRateList = response.data;
      });
      $scope.redirectCommodityManage = function () {
        $location.path('/tab/commodityManage');
      };
      if ('' === $state.params.enterpriseProductId) {
        $scope.pageType = 'insert';
        $scope.isDiscounted = true;
        $scope.isDiscountedPolicyType = false;
        $scope.product = {
          discounted: 'N'
        };
      } else {
        $scope.pageType = 'update';
        commodityManageService.getCommodity($state.params.enterpriseProductId).then(function (response) {
          $scope.product = {
            enterpriseProductId: response.data.enterpriseProductId,
            enterpriseCommodityCode: response.data.enterpriseCommodityCode,
            meteringUnit: response.data.meteringUnit,
            price: response.data.price,
            productName: response.data.productName,
            specificationModel: response.data.specificationModel,
            taxBureauCommodityCode: response.data.taxClassificationCode,
            taxClassificationCode: response.data.taxClassificationCode,
            taxClassificationName: response.data.taxClassificationName,
            taxPriceMarked: response.data.taxPriceMarked
          };
          if ('' != response.addedTaxSpecial && undefined != response.addedTaxSpecial) {
            $scope.isDiscounted = false;
            $scope.discountedPolicyTypeList = response.addedTaxSpecial.split(',');
            if ('N' === response.data.discounted) {
              $scope.isDiscountedPolicyType = false;
              $scope.product.discounted = 'N';
              $scope.product.discountedPolicyType = '';
            } else {
              $scope.isDiscountedPolicyType = true;
              $scope.product.discounted = 'Y';
              $scope.product.discountedPolicyType = response.data.discountedPolicyType;
            }
          } else {
            $scope.isDiscounted = true;
            $scope.discountedPolicyTypeList = [];
            $scope.isDiscountedPolicyType = false;
            $scope.product.discounted = 'N';
            $scope.product.discountedPolicyType = '';
          }
          angular.forEach($scope.taxRateList, function (value) {
            if(value.taxRateId === response.data.taxRateId){
              $scope.product.taxRate = response.data.taxRateId;
            }
          });
        });
      }
      taxTypeListModal();
      $scope.showTaxTypeListModal = function () {
        initModalPage();
        getTaxTypeList();
        $scope.taxTypeListModal.show();
      };
      $scope.hideTaxTypeListModal = function () {
        $scope.search.codeOrName = '';
        $scope.taxTypeListModal.hide();
      };
      $scope.searchTaxType = function () {
        getTaxTypeList();
      };
      $scope.onRefresh = function () {
        initModalPage();
        getTaxTypeList();
        $scope.$broadcast("scroll.refreshComplete");
      };
      $scope.onInfinite = function () {
        if ($scope.totalPage != 0 && $scope.pageIndex === $scope.totalPage) {
          $scope.canLoadMoreData = false;
          return;
        }
        $scope.pageIndex++;
        getTaxTypeList();
        $scope.$broadcast("scroll.infiniteScrollComplete");
      };
      $scope.moreDataCanBeLoaded = function () {
        return $scope.canLoadMoreData;
      };
      $scope.selectTaxType = function (taxType) {
        if ('' != taxType.addedTaxSpecial && undefined != taxType.addedTaxSpecial) {
          $scope.isDiscounted = false;
          $scope.discountedPolicyTypeList = taxType.addedTaxSpecial.split(',');
        } else {
          $scope.isDiscounted = true;
          $scope.discountedPolicyTypeList = [];
        }
        $scope.isDiscountedPolicyType = false;
        $scope.product.discounted = 'N';
        $scope.product.discountedPolicyType = '';
        $scope.product.taxBureauCommodityCode = taxType.mergeCoding;
        $scope.product.taxClassificationCode = taxType.mergeCoding;
        $scope.product.taxClassificationName = taxType.goodsName;
        $scope.search.codeOrName = '';
        $scope.taxTypeListModal.hide();
      };
      $scope.validProductCode = function () {
        if (undefined != $scope.product.enterpriseCommodityCode) {
          if ('insert' === $scope.pageType) {
            commodityManageService.validProductCodeForInsert($scope.product.enterpriseCommodityCode).then(function (response) {
              if (false === response.data) {
                $scope.isExistEnterpriseCommodityCode = true;
              } else {
                $scope.isExistEnterpriseCommodityCode = false;
              }
            });
          } else {
            commodityManageService.validProductCodeForUpdate($scope.product.enterpriseCommodityCode, $state.params.enterpriseProductId).then(function (response) {
              if (false === response.data) {
                $scope.isExistEnterpriseCommodityCode = true;
              } else {
                $scope.isExistEnterpriseCommodityCode = false;
              }
            });
          }
        }
      };
      $scope.changeDiscounted = function () {
        if ('Y' === $scope.product.discounted) {
          $scope.isDiscountedPolicyType = true;
          $scope.product.discountedPolicyType = $scope.discountedPolicyTypeList[0];
        } else {
          $scope.product.discountedPolicyType = '';
          $scope.isDiscountedPolicyType = false;
        }
      };
      $scope.saveCommodity = function () {
        commonUtil.loadingShow($ionicLoading);
        commodityManageService.saveCommodity($scope.product).then(function (response) {
          $ionicLoading.hide();
          var popup = commonUtil.popupShow($ionicPopup, "提示", '200' === response.code ? '保存成功' : '保存失败');
          popup.then(function () {
            if ('200' === response.code) {
              $location.path('/tab/commodityManage');
            }
          });
          commonUtil.timeout($timeout, popup);
        });
      };
      $scope.saveCommodityAndInsertCommodity = function (formObject) {
        commonUtil.loadingShow($ionicLoading);
        commodityManageService.saveCommodity($scope.product).then(function (response) {
          $ionicLoading.hide();
          var popup = commonUtil.popupShow($ionicPopup, "提示", '200' === response.code ? '保存成功' : '保存失败');
          popup.then(function () {
            if ('200' === response.code) {
              $scope.product = {
                discounted: 'N'
              };
              $scope.isDiscounted = true;
              $scope.isDiscountedPolicyType = false;
              $scope.isExistEnterpriseCommodityCode = false;
              $scope.taxTypeList = [];
              formObject.$setPristine();
            }
          });
          commonUtil.timeout($timeout, popup);
        });
      };
      $scope.updateCommodity = function () {
        commonUtil.loadingShow($ionicLoading);
        commodityManageService.updateCommodity($scope.product).then(function (response) {
          $ionicLoading.hide();
          var popup = commonUtil.popupShow($ionicPopup, "提示", '200' === response.code ? '保存成功' : '保存失败');
          popup.then(function () {
            if ('200' === response.code) {
              $location.path('/tab/commodityManage');
            }
          });
          commonUtil.timeout($timeout, popup);
        });
      };
      function initModalPage() {
        $scope.pageIndex = 0;
        $scope.pageSize = 6;
        $scope.totalPage = 0;
        $scope.taxTypeList = [];
        $scope.canLoadMoreData = false;
      }
      function taxTypeListModal() {
        $ionicModal.fromTemplateUrl("taxTypeList-modal.html", {
          scope: $scope,
          animation: "slide-in-up"
        }).then(function (modal) {
          $scope.taxTypeListModal = modal;
        });
      }
      function getTaxTypeList() {
        commodityManageService.getTaxTypeList($scope.pageIndex, $scope.pageSize = 6, $scope.search.codeOrName).then(function (response) {
          $scope.totalPage = response.data.pageCount;
          if (response.data.page.length > 0) {
            if (0 === $scope.taxTypeList.length) {
              $scope.taxTypeList = response.data.page;
            } else {
              angular.forEach(response.data.page, function (item) {
                $scope.taxTypeList.push(item);
              });
            }
          }
          $timeout(function () {
            if (response.data.page.length < $scope.pageSize) {
              $scope.canLoadMoreData = false;
            } else {
              $scope.canLoadMoreData = true;
            }
          }, 1000);
        });
      }
    }])
});
