define(['angular', 'commonUtil', 'validUtil'], function (angular, commonUtil, validUtil) {
  angular.module('customerManage.controller', [])
    .controller('customerList.controller', ['$scope', '$state', '$ionicPopup', '$ionicLoading', '$timeout', 'customerManageService',
      function ($scope, $state, $ionicPopup, $ionicLoading, $timeout, customerManageService) {
        $scope.$on('$ionicView.beforeEnter',function(){
          initPage($scope);
          getCustomerListPage($scope, $timeout, customerManageService);
        });
        $scope.doRefresh = function (customerNameOrCode) {
          initPage($scope);
          $scope.customerNameOrCode = typeof(customerNameOrCode) == "undefined" ? "" : customerNameOrCode;
          getCustomerListPage($scope, $timeout, customerManageService);
          $scope.$broadcast("scroll.refreshComplete");
        };
        $scope.loadMore = function (customerNameOrCode) {
          if ($scope.page === $scope.totalPage) {
            $scope.canLoadMoreData = false;
            return;
          }
          $scope.page += 1;
          $scope.customerNameOrCode = typeof(customerNameOrCode) == "undefined" ? "" : customerNameOrCode;
          getCustomerListPage($scope, $timeout, customerManageService);
          $timeout(function () {
            $scope.$broadcast("scroll.infiniteScrollComplete");
          }, 1500);

        };
        $scope.moreDataCanBeLoaded = function () {
          return $scope.canLoadMoreData;
        };
        $scope.deleteCustomer = function (cus, index) {
          $ionicPopup.confirm({
            title: '提示',
            template: '确定要删除吗？',
            cancelText: '取消',
            okText: '确认'
          }).then(function (res) {
            if (res) {
              commonUtil.loadingShow($ionicLoading);
              customerManageService.deleteCustomerById(cus.enterpriseCustomerId).then(function (response) {
                $ionicLoading.hide();
                var myPopup = commonUtil.popupShow($ionicPopup, "提示", '200' === response.code ? '删除成功' : '删除失败');
                if (response.code === "200") {
                  $scope.lists.splice(index);
                }
                commonUtil.timeout($timeout, myPopup);
              });
            }
          });
        }
      }])
    .controller('customerDetail.controller', ['$scope', '$state', 'customerManageService', function ($scope, $state, customerManageService) {
      var id = $state.params.enterpriseCustomerId;
      customerManageService.getCustomerById(id).then(function (response) {
        $scope.cus = response.data;
      }, function (err) {
        console.log(err);
      });
    }])
    .controller('customerInsert.controller', ['$scope', '$state', '$ionicPopup', '$ionicLoading', '$timeout', 'customerManageService', function ($scope, $state, $ionicPopup, $ionicLoading, $timeout, customerManageService) {
      $scope.notValidPhone = false;
      $scope.notValidEmail = false;
      $scope.notValidName = false;
      $scope.notValidCustomerName = false;
      $scope.notValidCustomerCode = false;
      $scope.notValidBankName = false;
      var id = $state.params.enterpriseCustomerId;
      if (typeof(id) != "undefined") {
        customerManageService.getCustomerById(id).then(function (response) {
          $scope.cus = response.data;
          $scope.customerTitle = '客户编辑';
        });
      } else {
        $scope.cus = new Object();
        $scope.customerTitle = '客户新增';
      }
      $scope.saveCustomer = function () {
        var params = $scope.cus;
        commonUtil.loadingShow($ionicLoading);
        if ($scope.cus.enterpriseCustomerId) {
          customerManageService.modifyCustomer(params).then(function (response) {
            $ionicLoading.hide();
            var myPopup = commonUtil.popupShow($ionicPopup, "提示", '200' === response.code ? '保存成功' : '保存失败');
            myPopup.then(function () {
              $state.go("tab.customerManageController", {}, {reload: true});
            });
            commonUtil.timeout($timeout, myPopup);
          });
        } else {
          customerManageService.insertCustomer(params).then(function (response) {
            $ionicLoading.hide();
            var myPopup = commonUtil.popupShow($ionicPopup, "提示", '200' === response.code ? '保存成功' : '保存失败');
            myPopup.then(function () {
              $state.go("tab.customerManageController", {}, {reload: true});
            });
            commonUtil.timeout($timeout, myPopup);
          });
        }
      };
      $scope.validPhone = function () {
        if (!validUtil.phoneValid($scope.cus.contactPhone)) {
          $scope.notValidPhone = true;
        } else {
          $scope.notValidPhone = false;
        }
      };
      $scope.validEmail = function () {
        if (!validUtil.emailValid($scope.cus.contactEmail)) {
          $scope.notValidEmail = true;
        } else {
          $scope.notValidEmail = false;
        }
      };
      $scope.validName = function () {
        if (!validUtil.nameValid($scope.cus.contactName)) {
          $scope.notValidName = true;
        } else {
          $scope.notValidName = false;
        }
      };
      $scope.validCustomerName = function () {
        if (!validUtil.customerNameValid($scope.cus.customerName)) {
          $scope.notValidCustomerName = true;
        } else {
          $scope.notValidCustomerName = false;
        }
      };
      $scope.validCustomerCode = function () {
        if (!validUtil.charNumValid($scope.cus.customerCode)) {
          $scope.notValidCustomerCode = true;
        } else {
          $scope.notValidCustomerCode = false;
        }
      };
      $scope.validBankName = function () {
        if (!validUtil.bankNameValid($scope.cus.bankAccount)) {
          $scope.notValidBankName = true;
        } else {
          $scope.notValidBankName = false;
        }
      };
    }])
  function initPage($scope) {
    $scope.page = 0;
    $scope.rows = 6;
    $scope.totalPage = 0;
    $scope.canLoadMoreData = false;
    $scope.customerNameOrCode = "";
    $scope.lists = new Array();
  }
  function getCustomerListPage($scope, $timeout, customerManageService) {
    customerManageService.getCustomerList($scope.page, $scope.rows, $scope.customerNameOrCode).then(function (response) {
      $scope.totalPage = response.pageCount;
      var responseData = response.data.page;
      if (responseData.length > 0) {
        if ($scope.lists.length == 0) {
          $scope.lists = responseData;
        } else {
          for (var i = 0; i < responseData.length; i++) {
            $scope.lists.push(responseData[i]);
          }
        }
      }
      $timeout(function () {
        if (responseData.length < $scope.rows) {
          $scope.canLoadMoreData = false;
        } else {
          $scope.canLoadMoreData = true;
        }
      }, 1000);
    });
  }
});
