define(['angular','commonUtil','validUtil','ajax_factory'], function (angular,commonUtil,validUtil,ajax_factory) {

  angular.module('enterpriseInfo.controller',[])

    .controller('enterpriseInfoList.controller', ['$scope','$state','$ionicPopup','enterpriseInfoService',
      function($scope,$state,$ionicPopup,enterpriseInfoService){
        var downloadUrl = ajax_factory.getPath("download");
        getEnterpriseInfo($scope,enterpriseInfoService);

        $scope.imgSrc = downloadUrl;
      }])
    .controller('enterpriseInfoEdit.controller', ['$scope','$ionicModal','$state','$ionicPopup','$ionicLoading','$timeout','enterpriseInfoService','systemManageService',
      'imgUploadService',function($scope,$ionicModal,$state,$ionicPopup,$ionicLoading,$timeout,enterpriseInfoService,systemManageService,imgUploadService){
        $scope.notValidPhone = false;
        $scope.notValidEmail = false;

        var downloadUrl = ajax_factory.getPath("download");
        getEnterpriseInfo($scope,enterpriseInfoService);
        $scope.imgSrc = downloadUrl;
        $scope.saveEnterpriseInfo= function() {
          //loading提示框，防止重复提交
          commonUtil.loadingShow($ionicLoading);

          var params = $scope.enterInfo;
          params.paperTicketed = params.paperTicketed == true ? "yes" : "no";

          enterpriseInfoService.saveInfo(params).then(function (response) {
            //对应loadingShow，关闭loading
            $ionicLoading.hide();
            //提示框
            var myPopup = commonUtil.popupShow($ionicPopup,"提示", '200' === response.code ? '保存成功' : '保存失败');

            myPopup.then(function () {
              $state.go("tab.enterpriseInfoController", {}, {reload: true});
            });
            //自动关闭提示框
            commonUtil.timeout($timeout, myPopup);
          });
        };

        $scope.validPhone = function(){
          if(!validUtil.phoneValid($scope.enterInfo.contactsPhone)){
            $scope.notValidPhone = true;
          }else{
            $scope.notValidPhone = false;
          }
        }

        $scope.validEmail = function(){
          if(!validUtil.emailValid($scope.enterInfo.contactsEmail)){
            $scope.notValidEmail = true;
          }else{
            $scope.notValidEmail = false;
          }
        }

        $ionicModal.fromTemplateUrl('province-modal.html', {
          scope: $scope,
          animation: 'slide-in-left'
        }).then(function(modal) {
          $scope.provinceModal = modal;
        });

        $ionicModal.fromTemplateUrl('city-modal.html', {
          scope: $scope,
          animation: 'slide-in-left'
        }).then(function(modal) {
          $scope.cityModal = modal;
        });

        $scope.getProvinceAddress = function(){
          getProvinceList($scope,systemManageService);
          $scope.provinceModal.show();
        }

        $scope.getCityAddress = function(parentCode){
          $scope.parentCode = parentCode;
          getCityList($scope,systemManageService);
          $scope.cityModal.show();
        }

        $scope.hideProvinceModal = function(){
          $scope.provinceModal.hide();
        }

        $scope.hideCityModal = function(){
          $scope.cityModal.hide();
        }

        $scope.selectAddress = function(cityCode){
          $scope.cityList = $scope.cityList2;
          $scope.enterInfo.provinceId = $scope.parentCode;
          $scope.enterInfo.cityId = cityCode;
          $scope.provinceModal.hide();
          $scope.cityModal.hide();
        }

        //拍照功能
        $scope.show = function(event) {
          console.log(event);
          //window._curImgId = ($(event.target).prev('img')[0]).id;
          $ionicPopup.show({
            title: '上传图片',
            scope: $scope,
            buttons: [
              { text: '拍照' ,
                onTap : function () {
                  $scope.takeCameraPicture();
                }},
              {text: '相册',
                onTap : function () {
                  $scope.pickImg();
                }},
              {text: '取消'}
            ]
          });
        };
        var callback = function(r) {
          $ionicLoading.hide();
          var res = angular.fromJson(r.response);
          if(res.code !== "200"){
              var myPopup = commonUtil.popupShow($ionicPopup,"提示", '上传失败，请上传JPG、PNG、JPEG、BMP格式的图片，长宽各小于1024像素，并不大于2M。');
              //自动关闭提示框
              commonUtil.timeout($timeout, myPopup);
          }else{
              var socialCodeCertificate = res.data.imgUrl;
              $scope.enterInfo.socialCodeCertificate = socialCodeCertificate;
              $scope.imgSrc = downloadUrl + "?socialCodeCertificate=" + socialCodeCertificate;
              $scope.$apply();
          }
        };

        $scope.pickImg = function(){
          imgUploadService.pickImg(callback);
        };

        $scope.takeCameraPicture = function(){
          imgUploadService.takeCameraPicture(callback);
        };
      }])
    .filter("paperTicketFilter", function(){
        return function(input){
          return input === true ? "是":"否";
        }
      }
    )
    .filter("paperTicketToggleFilter", function(){
        return function(input){
          return input === "no" ? false:true;
        }
      }
    )
    .filter("provinceFilter", function(){
        return function(input,provinceList){
          if(typeof(input) != "undefined" && typeof(provinceList) != "undefined"){
            for(var i = 0; i < provinceList.length; i++){
              if(input == provinceList[i].areaCode){
                return provinceList[i].areaName;
              }
            }
          }
        }
      }
    )
    .filter("cityFilter", function() {
        return function (input, cityList) {
          if (typeof(input) != "undefined" && typeof(cityList) != "undefined") {
            for (var i = 0; i < cityList.length; i++) {
              if (input == cityList[i].areaCode) {
                return cityList[i].areaName;
              }
            }
          }
        }
      }
    )
  function getEnterpriseInfo($scope,enterpriseInfoService){
    enterpriseInfoService.getEnterpriseInfo().then(function (response) {
      $scope.enterInfo = response.data.enterpriseInfo;
      //将是否开具发票no、yes转化成false、true，保存时需要进行反向转换
      $scope.enterInfo.paperTicketed = $scope.enterInfo.paperTicketed === "yes" ? true : false;
      $scope.provinceList = response.data.provinceList;
      $scope.cityList = response.data.cityList;
    });
  }

  function getProvinceList($scope,systemManageService) {
    systemManageService.getProvinceAddr().then(function (response) {
      $scope.provinceList2 = response.data;
    });
  }
  function getCityList($scope,systemManageService) {
    systemManageService.getCityAddr($scope.parentCode).then(function (response) {
      $scope.cityList2 = response.data;
    });
  }

});
