define(['angular', 'commonUtil', 'validUtil'], function (angular, commonUtil, validUtil) {

  angular.module('invoiceClerkManage.controller', [])

    .controller('invoiceClerkManageList.controller', ['$scope', '$state', '$ionicModal', '$ionicPopup', '$ionicLoading', '$timeout', 'invoiceClerkManageService',
      function ($scope, $state, $ionicModal, $ionicPopup, $ionicLoading, $timeout, invoiceClerkManageService) {

        $scope.notValidName = false;
        $scope.notValidPhone = false;
        $scope.notValidLoginName = false;
        $scope.notValidPassword = false;
        $scope.ifEqualNewPwd = false;
        $scope.ifRequired = false;
        $scope.isExistLoginName = false;

        //请求开票员信息列表
        initPage($scope);
        getInvoiceClerkManage($scope, $timeout, invoiceClerkManageService);

        $scope.doRefresh = function () {
          initPage($scope);
          getInvoiceClerkManage($scope, $timeout, invoiceClerkManageService);
          $scope.$broadcast("scroll.refreshComplete");
        }

        $scope.loadMore = function () {
          if ($scope.page === $scope.totalPage) {
            $scope.canLoadMoreData = false;
            return;
          }
          $scope.page += 1;
          getInvoiceClerkManage($scope, $timeout, invoiceClerkManageService);
          $timeout(function () {
            $scope.$broadcast("scroll.infiniteScrollComplete");
          }, 1500);

        }

        $scope.moreDataCanBeLoaded = function () {
          return $scope.canLoadMoreData;
        }

        $scope.checkLoginName = function () {
          if (validUtil.loginNameValid($scope.clerk.loginName)) {
            invoiceClerkManageService.checkLoginName($scope.clerk.loginName).then(function (response) {
              if (false === response.data) {
                $scope.isExistLoginName = true;
              } else {
                $scope.isExistLoginName = false;
              }
            });
          }
        };

        $scope.validName = function () {
          if (!validUtil.nameValid($scope.clerk.clerkName)) {
            $scope.notValidName = true;
          } else {
            $scope.notValidName = false;
          }
        }

        $scope.validPhone = function () {
          if (!validUtil.phoneValid($scope.clerk.contractPhone)) {
            $scope.notValidPhone = true;
          } else {
            $scope.notValidPhone = false;
          }
        }

        $scope.validLoginName = function () {
          $scope.isExistLoginName = false;
          if (!validUtil.loginNameValid($scope.clerk.loginName)) {
            $scope.notValidLoginName = true;
          } else {
            $scope.notValidLoginName = false;
          }
        }

        $scope.validPassword = function () {
          var loginPwd = $scope.clerk.loginPassword;
          var confirmPwd = $scope.clerk.passwordNewConfirm;
          //更新必输项
          if ($scope.flag === "add" && loginPwd === "") {
            $scope.ifRequired = true;
          } else {
            $scope.ifRequired = false;
          }

          if (loginPwd !== "" && confirmPwd !== loginPwd) {
            $scope.ifEqualNewPwd = true;
          } else {
            $scope.ifEqualNewPwd = false;
          }

          if (loginPwd !== "" && !validUtil.passwordValid(loginPwd)) {
            $scope.notValidPassword = true;
          } else {
            $scope.notValidPassword = false;
          }
        }

        $scope.validConfirmPassword = function () {
          var loginPwd = $scope.clerk.loginPassword;
          var confirmPwd = $scope.clerk.passwordNewConfirm;
          if (loginPwd !== "" && confirmPwd !== loginPwd) {
            $scope.ifEqualNewPwd = true;
          } else {
            $scope.ifEqualNewPwd = false;
          }
        }

        //点击模态窗口的保存功能
        $scope.saveInvoiceClerkMsg = function (index) {
          //loading提示框，防止重复提交
          commonUtil.loadingShow($ionicLoading);

          var params = $scope.clerk;
          delete params["passwordNewConfirm"];
          //add是作为标记区分编辑和添加
          if ("add" === $scope.flag) {

            invoiceClerkManageService.addClerkMsg(params).then(function (response) {
              //对应loadingShow，关闭loading
              $ionicLoading.hide();
              //提示框
              var myPopup = commonUtil.popupShow($ionicPopup, "提示", '200' === response.code ? '保存成功' : '保存失败');

              if (response.code === "200") {
                //$scope.lists.push($scope.clerk);
                initPage($scope);
                getInvoiceClerkManage($scope, $timeout, invoiceClerkManageService);
                $scope.clerkModal.hide();
              }
              //自动关闭提示框
              commonUtil.timeout($timeout, myPopup);
            });
          } else {
            invoiceClerkManageService.editClerkMsg(params).then(function (response) {
              //对应loadingShow，关闭loading
              $ionicLoading.hide();
              //提示框
              var myPopup = commonUtil.popupShow($ionicPopup, "提示", '200' === response.code ? '保存成功' : '保存失败');

              if (response.code === "200") {
                //getInvoiceClerkManage($scope, $timeout, invoiceClerkManageService);
                $scope.lists[index] = $scope.clerk;
                $scope.clerkModal.hide();
              }
              //自动关闭提示框
              commonUtil.timeout($timeout, myPopup);
            });
          }
        };

        $ionicModal.fromTemplateUrl("clerk-modal.html", {
          scope: $scope,
          animation: "slide-in-up",
        }).then(function (modal) {
          $scope.clerkModal = modal;
        });
        /**
         * 开票员启用和禁用
         * @param cus
         */
        $scope.changeState = function (clerk) {
          var params = clerk;
          if (clerk.validStatus === "VALID") {
            $ionicPopup.confirm({
              title: '提示',
              template: '<p class="pop-center">确定要禁用吗？</p>',
              cancelText: '取消',
              okText: '确认'
            }).then(function (res) {
              if (res) {
                invoiceClerkManageService.disableClerkState(params).then(function (response) {
                  if (response.code === "200") {
                    clerk.validStatus = "INVALID";
                  }
                });
              }
            });
          } else {
            $ionicPopup.confirm({
              title: '提示',
              template: '<p class="pop-center">确定要启用吗？</p>',
              cancelText: '取消',
              okText: '确认'
            }).then(function (res) {
              if (res) {
                invoiceClerkManageService.enableClerkState(params).then(function (response) {
                  if (response.code === "200") {
                    clerk.validStatus = "VALID";
                  }
                });
              }
            });

          }
        }

        $scope.openModal = function (clerk, index) {

          if ("add" === clerk) {
            $scope.modalTitle = '开票员新增',
            $scope.flag = "add";
            $scope.ifRequired = true;
            $scope.clerk = {
              "clerkName": "",
              "loginName": "",
              "mechanism": "",
              "contractPhone": "",
              "loginPassword": "",
              "passwordNewConfirm": "",
            };
          } else {
            $scope.modalTitle = '开票员编辑',
            $scope.flag = "modify";
            $scope.ifRequired = false;
            $scope.enterpriseBillingClerkId = clerk.enterpriseBillingClerkId;
            $scope.index = index
            getInvoiceClerkMsgById($scope, invoiceClerkManageService);
          }
          $scope.clerkModal.show();
        };
        //关闭模态窗口
        $scope.closeModal = function () {
          $scope.clerkModal.hide();
        };

      }])
    .filter("statusFilter", function () {
        return function (input, status) {
          if (status) {
            return (input === "VALID") ? "启用" : "禁用";
          } else {
            return (input === "VALID") ? "禁用" : "启用";
          }

        }
      }
    )


  function initPage($scope) {
    $scope.page = 1;
    $scope.rows = 6;
    $scope.totalPage = 0;
    $scope.canLoadMoreData = false;
    $scope.lists = new Array();
  }

  function getInvoiceClerkManage($scope, $timeout, invoiceClerkManageService) {
    invoiceClerkManageService.getInvoiceClerkManageList($scope.page, $scope.rows).then(function (response) {
      $scope.totalPage = response.data.totalPage;
      var responseData = response.data.clerkList;
      if (responseData.length > 0) {
        if ($scope.lists.length == 0) {
          $scope.lists = responseData;
        } else {
          for (var i = 0; i < responseData.length; i++) {
            $scope.lists.push(responseData[i]);
          }
        }
      }
      $timeout(function () {
        if (responseData.length < $scope.rows) {
          $scope.canLoadMoreData = false;
        } else {
          $scope.canLoadMoreData = true;
        }
      }, 1000);

    });
  }


  function getInvoiceClerkMsgById($scope, invoiceClerkManageService) {
    invoiceClerkManageService.getInvoiceClerkMsgById($scope.enterpriseBillingClerkId).then(function (response) {
      $scope.clerk = response.data;
      $scope.index = $scope.index;
      $scope.clerk.loginPassword = "";
      $scope.clerk.passwordNewConfirm = "";
    });
  }

});
