define(['angular', 'commonUtil'], function (angular, commonUtil) {
  angular.module('invoiceManage.controller', [])
    .filter('fsztFilter', function () {
      return function (object) {
        if ('NOSEND' === object) {
          return '未发送';
        } else if ('SENDSUCCESS' === object) {
          return '发送成功';
        } else if ('SENDFAIL' === object) {
          return '发送失败';
        } else {
          return '部分成功';
        }
      }
    })
    .controller('invoiceList', ['$scope', '$ionicPopup', '$ionicLoading', '$timeout', '$filter', '$location', 'invoiceManageService', function ($scope, $ionicPopup, $ionicLoading, $timeout, $filter, $location, invoiceManageService) {
      $scope.kpzt = 'NOMAKEINVOICE';
      initPage();
      getInvoiceList($scope.kpzt);
      $scope.buttonStyle = function (kpzt) {
        return $scope.kpzt === kpzt;
      };
      $scope.onRefresh = function () {
        initPage();
        getInvoiceList($scope.kpzt);
        $scope.$broadcast("scroll.refreshComplete");
      };
      $scope.onInfinite = function () {
        if ($scope.pageIndex === $scope.totalPage) {
          $scope.canLoadMoreData = false;
          return;
        }
        $scope.pageIndex++;
        getInvoiceList($scope.kpzt);
        $scope.$broadcast("scroll.infiniteScrollComplete");
      };
      $scope.getInvoiceList = function (kpzt) {
        initPage();
        $scope.kpzt = kpzt;
        getInvoiceList(kpzt);
      };
      $scope.invoiceDetailPage = function (fpqqlsh) {
        $location.path('/tab/invoiceInsert/' + fpqqlsh);
      };
      $scope.billing = function (index, fpqqlsh) {
        commonUtil.loadingShow($ionicLoading);
        invoiceManageService.billingInvoice(fpqqlsh).then(function (response) {
          $ionicLoading.hide();
          var popup = commonUtil.popupShow($ionicPopup, "提示", '200' === response.code ? '请求成功，系统将自动为您开票' : '请求失败');
          popup.then(function () {
            $scope.invoiceList.splice(index, 1);
          });
          commonUtil.timeout($timeout, popup);
        });
      };
      $scope.remove = function (index, fpqqlsh) {
        $ionicPopup.confirm({
          title: '删除发票',
          template: '确定要删除该发票?',
          cancelText: '取消',
          okText: '确认'
        }).then(function (confirm) {
          if (confirm) {
            commonUtil.loadingShow($ionicLoading);
            invoiceManageService.removeInvoice(fpqqlsh).then(function (response) {
              $ionicLoading.hide();
              var popup = commonUtil.popupShow($ionicPopup, "提示", '200' === response.code ? '删除成功' : '删除失败');
              popup.then(function () {
                if ('200' === response.code) {
                  $scope.invoiceList.splice(index, 1);
                }
              });
              commonUtil.timeout($timeout, popup);
            });
          }
        });
      };
      $scope.showSendDetail = function (fszt, sprSjh, sprYx, sprMc, fpDmFpHm) {
        showSendDetailPopup(fszt, sprSjh, sprYx, sprMc, fpDmFpHm);
      };
      $scope.download = function (fpqqlsh) {
        console.log(fpqqlsh);
        console.log('进行下载操作');
      };
      $scope.showFailureReason = function (sbyy) {
        commonUtil.popupShow($ionicPopup, "失败原因", sbyy);
      };
      $scope.moreDataCanBeLoaded = function () {
        return $scope.canLoadMoreData;
      };
      function initPage() {
        $scope.pageIndex = 1;
        $scope.pageSize = 6;
        $scope.totalPage = 0;
        $scope.invoiceList = [];
        $scope.canLoadMoreData = false;
      }

      function getInvoiceList(kpzt) {
        commonUtil.loadingShow($ionicLoading);
        invoiceManageService.getInvoiceList($scope.pageIndex, $scope.pageSize, kpzt).then(function (response) {
          $ionicLoading.hide();
          $scope.totalPage = response.data.pages;
          if (response.data.list.length > 0) {
            if (0 === $scope.invoiceList.length) {
              $scope.invoiceList = response.data.list;
            } else {
              angular.forEach(response.data.list, function (item) {
                $scope.invoiceList.push(item);
              });
            }
          }
          $timeout(function () {
            if (response.data.list.length < $scope.pageSize) {
              $scope.canLoadMoreData = false;
            } else {
              $scope.canLoadMoreData = true;
            }
          }, 1000);
        });
      }

      function showSendDetailPopup(fszt, sprSjh, sprYx, sprMc, fpDmFpHm) {
        $scope.sendmessage = {
          sprSjh: sprSjh,
          sprYx: sprYx,
          sprMc: sprMc,
          fpDmFpHm: fpDmFpHm
        };
        var msgStr, emailStr;
        if ('NOSEND' === fszt) {
          msgStr = "<i class='icon ion-help'>短信未发送</i>";
          emailStr = "<i class='icon ion-help'>邮件未发送</i>";
        } else if ('SENDSUCCESS' === fszt) {
          msgStr = "<i class='icon ion-checkmark-round'>短信发送成功</i>";
          emailStr = "<i class='icon ion-checkmark-round'>邮件发送成功</i>";
        } else if ('SENDFAIL' === fszt) {
          msgStr = "<i class='icon ion-close-round'>短信发送失败</i>";
          emailStr = "<i class='icon ion-close-round'>邮件发失败</i>";
        } else {
          if ("" === sprSjh || null === sprSjh) {
            msgStr = "<i class='icon ion-help'>手机号未填写</i>";
          } else {
            msgStr = "<i class='icon ion-checkmark-round'>短信发送成功</i>";
          }
          if ("" === sprYx || null === sprYx) {
            emailStr = "<i class='icon ion-help'>邮箱未填写</i>";
          } else {
            emailStr = "<i class='icon ion-checkmark-round'>邮件发送成功</i>";
          }
        }
        $ionicPopup.show({
          template: '<p class="pop-center">' + msgStr + '</p><p class="pop-center">' + emailStr + '</p>',
          title: '发送状态',
          scope: $scope,
          buttons: [
            {text: '取消'},
            {
              text: '继续发送',
              onTap: function () {
                $ionicPopup.show({
                  template: '' +
                  '<div class="row pt-send"><div class="col-33">收票人：</div><div class="col-67"><input type="text" ng-model="sendmessage.sprMc" /></div></div>' +
                  '<div class="row pt-send"><div class="col-33">手机：</div><div class="col-67"><input ng-model="sendmessage.sprSjh" type="text" /></div></div>' +
                  '<div class="row pt-send"><div class="col-33">邮箱：</div><div class="col-67"><input ng-model="sendmessage.sprYx" type="text" /></div></div>' +
                  '',
                  title: '发送提醒',
                  scope: $scope,
                  buttons: [
                    {text: '取消'},
                    {
                      text: '确定发送',
                      onTap: function () {
                        invoiceManageService.resendInvoice($scope.sendmessage).then(function (response) {
                          commonUtil.showPrompt($ionicLoading, '200' === response.code ? '发送成功' : '发送失败');
                          getInvoiceList($scope.kpzt);
                          $timeout(function () {
                            $ionicLoading.hide();
                          }, 2000);
                        });
                      }
                    }
                  ]
                });
              }
            }
          ]
        });
      }
    }])
});

