define(['angular', 'commonUtil', 'ajax_factory', 'validUtil'], function (angular, commonUtil, ajax_factory, validUtil) {
  angular.module('invoiceSetting.controller', [])
    .controller('invoiceSetting', ['$scope', '$location', '$filter', 'invoiceSettingService', function ($scope, $location, $filter, invoiceSettingService) {
      $scope.$on('$ionicView.beforeEnter',function(){
        invoiceSettingService.getInvoiceSetInfo().then(function (response) {
          $scope.invoiceSetInfo = {
            enterpriseInvoiceSettingsId: response.data.enterpriseInvoiceSettingsId,
            enterpriseBankAccountName: response.data.enterpriseBankAccountName,
            enterpriseAccountNumber: response.data.enterpriseAccountNumber,
            enterpriseContactPhone: response.data.enterpriseContactPhone,
            enterpriseType: response.data.enterpriseType,
            enterpriseTaxRates: response.data.enterpriseTaxRates,
            enterpriseTariff: response.data.enterpriseTariff
          };
        });
      });
      $scope.signature = ajax_factory.getPath("getSignature");
      $scope.redirectHome = function () {
        $location.path('/tab/home');
      };
      $scope.updateInvoiceSet = function () {
        $location.path('/tab/invoiceSetUpdate/' + $scope.invoiceSetInfo.enterpriseInvoiceSettingsId);
      };
    }])
    .controller('invoiceSetUpdate', ['$scope', '$state', '$ionicModal', '$ionicPopup', '$ionicLoading', '$filter', '$location', '$timeout', 'invoiceSettingService', function ($scope, $state, $ionicModal, $ionicPopup, $ionicLoading, $filter, $location, $timeout, invoiceSettingService) {
      $scope.$on('$ionicView.beforeEnter',function(){
        if ('' === $state.params.invoiceSettingsId) {
          $scope.pageType = 'insert';
          $scope.enterpriseInfo = {};
        } else {
          $scope.pageType = 'update';
          invoiceSettingService.getInvoiceSetInfo().then(function (response) {
            $scope.enterpriseInfo = {
              enterpriseRegInfoId: response.data.enterpriseRegInfoId,
              enterpriseBankAccountName: response.data.enterpriseBankAccountName,
              enterpriseAccountNumber: response.data.enterpriseAccountNumber,
              enterpriseContactPhone: response.data.enterpriseContactPhone,
              tariffPackageId: response.data.tariffPackageId,
              taxpayerTypeId: response.data.taxpayerTypeId,
              taxRateId: response.data.taxRateId
            };
          });
        }
      });
      $scope.signature = ajax_factory.getPath("getSignature");
      tariffPackagesModal();
      taxRatesModal();
      $scope.redirectInvoiceSetting = function () {
        $location.path('/tab/invoiceSetting');
      };
      $scope.validEnterpriseInfo = {
        validEnterpriseBankAccountNameStatus: false,
        validEnterpriseAccountNumberStatus: false,
        validEnterpriseContactPhoneStatus: false,
        enterpriseBankAccountNameChange: function () {
          if ('' !== $scope.enterpriseInfo.enterpriseBankAccountName && !validUtil.bankNameValid($scope.enterpriseInfo.enterpriseBankAccountName)) {
            $scope.validEnterpriseInfo.validEnterpriseBankAccountNameStatus = true;
          } else {
            $scope.validEnterpriseInfo.validEnterpriseBankAccountNameStatus = false;
          }
        },
        enterpriseAccountNumberChange: function () {
          if ('' !== $scope.enterpriseInfo.enterpriseAccountNumber && !validUtil.bankNumberValid($scope.enterpriseInfo.enterpriseAccountNumber)) {
            $scope.validEnterpriseInfo.validEnterpriseAccountNumberStatus = true;
          } else {
            $scope.validEnterpriseInfo.validEnterpriseAccountNumberStatus = false;
          }
        },
        enterpriseContactPhoneChange: function () {
          if ('' !== $scope.enterpriseInfo.enterpriseContactPhone && !validUtil.enterprisePhoneValid($scope.enterpriseInfo.enterpriseContactPhone)) {
            $scope.validEnterpriseInfo.validEnterpriseContactPhoneStatus = true;
          } else {
            $scope.validEnterpriseInfo.validEnterpriseContactPhoneStatus = false;
          }
        }
      };
      $scope.saveEnterpriseInfo = function () {
        invoiceSettingService.saveEnterpriseInfo($scope.enterpriseInfo).then(function (response) {
          if ('200' === response.code) {

            //暂时隐藏第二步
            // showTariffPackagesModal();
            //隐藏掉第二部之后的逻辑
            if('' === $scope.enterpriseInfo.tariffPackageId || undefined === $scope.enterpriseInfo.tariffPackageId){
              invoiceSettingService.initTariffPackage().then(function (response) {
                if ('200' === response.code) {
                  showTaxRatesModal();
                } else {
                  commonUtil.popupShow($ionicPopup, "提示", '系统异常');
                }
              });
            }else{
              showTaxRatesModal();
            }


          } else {
            commonUtil.popupShow($ionicPopup, "提示", '系统异常');
          }
          $scope.validEnterpriseInfo.validEnterpriseBankAccountNameStatus = false;
          $scope.validEnterpriseInfo.validEnterpriseAccountNumberStatus = false;
          $scope.validEnterpriseInfo.validEnterpriseContactPhoneStatus = false;
        });
      };
      $scope.hideTariffPackagesModal = function () {
        $scope.tariffPackagesModal.hide();
      };
      $scope.saveTariffPackage = function () {
        if ('' === $scope.tariffPackage.tariffPackageId || undefined === $scope.tariffPackage.tariffPackageId) {
          invoiceSettingService.initTariffPackage().then(function (response) {
            if ('200' === response.code) {
              $scope.tariffPackagesModal.hide();
              showTaxRatesModal();
            } else {
              commonUtil.popupShow($ionicPopup, "提示", '系统异常');
            }
          });
        } else {
          $scope.tariffPackagesModal.hide();
          showTaxRatesModal();
        }
      };
      $scope.hideTaxRatesModal = function () {
        $scope.taxRatesModal.hide();
        //暂时隐藏第二步
        // showTariffPackagesModal();
      };
      $scope.showTaxRates = function (index) {
        angular.forEach($scope.taxRateList, function (value, key) {
          if (index === key) {
            value.showFlag = !value.showFlag;
          } else {
            value.showFlag = false;
            angular.forEach(value.taxRates, function (item1) {
              item1.checkedFlag = false;
            });
          }
        });
      };
      /*对复选框进行监听*/
      var flag = 0;
      $scope.$watch('taxRateList', function (value) {
        angular.forEach(value, function (item1) {
          angular.forEach(item1.taxRates, function (item2) {
            if (item2.checkedFlag) {
              ++flag;
            }
          });
        });
        if (0 === flag) {
          $scope.taxRateFormInvalid = true;
        } else {
          $scope.taxRateFormInvalid = false;
        }
        flag = 0;
      }, true);
      $scope.taxRateStyle = function (index) {
        if (0 === index) {
          if ($scope.taxRateList[index].showFlag) {
            return 'icon ion-ios-person';
          } else {
            return 'icon ion-ios-person-outline';
          }
        } else {
          if ($scope.taxRateList[index].showFlag) {
            return 'icon ion-ios-people';
          } else {
            return 'icon ion-ios-people-outline';
          }
        }
      };
      $scope.saveTaxRates = function () {
        commonUtil.loadingShow($ionicLoading);
        var parameter = {
          taxpayerTypeId: '',
          taxRateId: ''
        };
        angular.forEach($scope.taxRateList, function (value) {
          if (value.showFlag) {
            parameter.taxpayerTypeId = value.taxpayerTypeId;
            angular.forEach(value.taxRates, function (item) {
              if (item.checkedFlag) {
                parameter.taxRateId += item.taxRateId;
                parameter.taxRateId += '|';
              }
            });
          }
        });
        parameter.taxRateId = parameter.taxRateId.substring(0, parameter.taxRateId.lastIndexOf('|'));
        invoiceSettingService.saveEnterpriseTaxRate(parameter).then(function (response) {
          $ionicLoading.hide();
          var popup = commonUtil.popupShow($ionicPopup, "提示", '200' === response.code ? '保存成功' : '保存失败');
          popup.then(function () {
            if ('200' === response.code) {
              $scope.taxRatesModal.hide();
              $location.path('/tab/invoiceSetting');
            }
          });
          $timeout(function () {
            popup.close();
            if ('200' === response.code) {
              $scope.taxRatesModal.hide();
              $location.path('/tab/invoiceSetting');
            }
          }, 2000);
        });
      };
      function showTariffPackagesModal() {
        invoiceSettingService.getTariffPackageList().then(function (response) {
          $scope.tariffPackage = {
            tariffPackageId: $scope.enterpriseInfo.tariffPackageId
          };
          $scope.tariffPackageList = response.data;
        });
        $scope.tariffPackagesModal.show();
      }

      function showTaxRatesModal() {
        invoiceSettingService.getTaxRateList().then(function (response) {
          $scope.taxRateList = response.data;
          if ('insert' === $scope.pageType) {
            angular.forEach($scope.taxRateList, function (value) {
              value.showFlag = false;
              angular.forEach(value.taxRates, function (item) {
                item.checkedFlag = false;
              });
            });
            $scope.taxRateFormInvalid = true;
          } else {
            angular.forEach($scope.taxRateList, function (value) {
              if ($scope.enterpriseInfo.taxpayerTypeId === value.taxpayerTypeId) {
                value.showFlag = true;
              } else {
                value.showFlag = false;
              }
              angular.forEach(value.taxRates, function (item) {
                if(-1 === $scope.enterpriseInfo.taxRateId.indexOf(item.taxRateId)){
                  item.checkedFlag = false;
                }else{
                  item.checkedFlag = true;
                }
              });
            });
            $scope.taxRateFormInvalid = false;
          }
          $scope.taxRatesModal.show();
        });
      }

      function tariffPackagesModal() {
        $ionicModal.fromTemplateUrl("tariffPackages-modal.html", {
          scope: $scope,
          animation: "slide-in-up"
        }).then(function (modal) {
          $scope.tariffPackagesModal = modal;
        });
      }

      function taxRatesModal() {
        $ionicModal.fromTemplateUrl("taxRates-modal.html", {
          scope: $scope,
          animation: "slide-in-up"
        }).then(function (modal) {
          $scope.taxRatesModal = modal;
        });
      }
    }]);
});
